@@ -22,7 +22,7 @@ def retain_filed_quotation(key, origin):
     if isinstance(origin, str):
         origin = f"'{origin}'"
     elif key == "type":
-        origin = origin.__repr__()
+        origin = origin.__str__()
     return origin
 
 
